window.Gleam.initSearch([{"doc":"glitr_convert_sql","title":"glitr_convert_sql","content":"# glitr_convert_sql\n\n[![Package Version](https://img.shields.io/hexpm/v/glitr_convert_sql)](https://hex.pm/packages/glitr_convert_sql)\n[![Hex Docs](https://img.shields.io/badge/hex-docs-ffaff3)](https://hexdocs.pm/glitr_convert_sql/)\n\n**Create SQL requests effortlessly using glitr_convert**\n\n## Installation\n\n```sh\ngleam add glitr_convert_sql\n```\n\n## Usage\n\n```gleam\nimport gleam/io\nimport glitr/convert as c\nimport glitr/convert/sql\n\npub type User {\n  User(id: String, name: String, age: Int)\n}\n\npub fn user_converter() -&gt; c.Converter(User) {\n  c.object({\n    use id &lt;- c.parameter\n    use name &lt;- c.parameter\n    use age &lt;- c.parameter\n    use &lt;- c.constructor\n    User(id:, name:, age:)\n  })\n  |&gt; c.field(&quot;id&quot;, fn(v) { Ok(v.id) }, c.string())\n  |&gt; c.field(&quot;name&quot;, fn(v) { Ok(v.name) }, c.string())\n  |&gt; c.field(&quot;age&quot;, fn(v) { Ok(v.age) }, c.int())\n  |&gt; c.to_converter\n}\n\npub fn main() {\n  let alice = User(&quot;1&quot;, &quot;Alice&quot;, 24)\n\n  sql.insert(&quot;users&quot;, user_converter(), [alice])\n  |&gt; io.debug\n  // INSERT INTO users (id, name, age) VALUES (&#39;1&#39;, &#39;Alice&#39;, 24);\n\n  let happy_birthday_alice = User(..alice, age: 25)\n\n  sql.update(&quot;users&quot;, user_converter(), alice, &quot;id&quot;)\n  |&gt; io.debug\n  // UPDATE users SET name=&#39;Alice&#39;, age=25 WHERE id=&#39;1&#39;;\n\n  sql.select(&quot;users&quot;, user_converter())\n  |&gt; io.debug\n  // SELECT id, name, age FROM users;\n}\n```\n\nFurther documentation can be found at &lt;https://hexdocs.pm/glitr_convert_sql&gt;.\n\n## Features\n\n- Select all requests\n- Insert requests\n- Update requests\n\n## Backlog\n\n- Select + where requests\n- Delete requests\n- Integrate more features like order by, returning and joins\n\n## Development\n\n```sh\ngleam run   # Run the project\ngleam test  # Run the tests\n```\n","url":"index.html"},{"doc":"glitr/convert/sql","title":"insert","content":"pub fn insert(\n  table: String,\n  converter: Converter(a),\n  values: List(a),\n) -&gt; String\n\nSynonyms:\nglitr/convert/sql.insert\nglitr/convert/sql insert","url":"glitr/convert/sql.html#insert"},{"doc":"glitr/convert/sql","title":"select","content":"pub fn select(table: String, converter: Converter(a)) -&gt; String\n\nSynonyms:\nglitr/convert/sql.select\nglitr/convert/sql select","url":"glitr/convert/sql.html#select"},{"doc":"glitr/convert/sql","title":"update","content":"pub fn update(\n  table: String,\n  converter: Converter(a),\n  value: a,\n  selector_col: String,\n) -&gt; String\n\nSynonyms:\nglitr/convert/sql.update\nglitr/convert/sql update","url":"glitr/convert/sql.html#update"},{"doc":"glitr/convert/sql","title":"glitr/convert/sql","content":"","url":"glitr/convert/sql.html"},{"doc":"glitr_convert_sql","title":"main","content":"pub fn main() -&gt; Nil\n\nSynonyms:\nglitr_convert_sql.main\nglitr_convert_sql main","url":"glitr_convert_sql.html#main"},{"doc":"glitr_convert_sql","title":"glitr_convert_sql","content":"","url":"glitr_convert_sql.html"}]);